==> huaweicloudsdkworkspace-3.1.133-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/show_script_detail_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowScriptDetailRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'script_id': 'str',
        'script_task_id': 'str'
    }

    attribute_map = {
        'script_id': 'script_id',
        'script_task_id': 'script_task_id'
    }

    def __init__(self, script_id=None, script_task_id=None):
        """ShowScriptDetailRequest

        The model defined in huaweicloud sdk

        :param script_id: 脚本ID。
        :type script_id: str
        :param script_task_id: 执行脚本的任务ID
        :type script_task_id: str
        """
        
        

        self._script_id = None
        self._script_task_id = None
        self.discriminator = None

        self.script_id = script_id
        if script_task_id is not None:
            self.script_task_id = script_task_id

    @property
    def script_id(self):
        """Gets the script_id of this ShowScriptDetailRequest.

        脚本ID。

        :return: The script_id of this ShowScriptDetailRequest.
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        """Sets the script_id of this ShowScriptDetailRequest.

        脚本ID。

        :param script_id: The script_id of this ShowScriptDetailRequest.
        :type script_id: str
        """
        self._script_id = script_id

    @property
    def script_task_id(self):
        """Gets the script_task_id of this ShowScriptDetailRequest.

        执行脚本的任务ID

        :return: The script_task_id of this ShowScriptDetailRequest.
        :rtype: str
        """
        return self._script_task_id

    @script_task_id.setter
    def script_task_id(self, script_task_id):
        """Sets the script_task_id of this ShowScriptDetailRequest.

        执行脚本的任务ID

        :param script_task_id: The script_task_id of this ShowScriptDetailRequest.
        :type script_task_id: str
        """
        self._script_task_id = script_task_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowScriptDetailRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspace-3.1.155-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/show_script_detail_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowScriptDetailRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'script_id': 'str',
        'script_task_id': 'str'
    }

    attribute_map = {
        'script_id': 'script_id',
        'script_task_id': 'script_task_id'
    }

    def __init__(self, script_id=None, script_task_id=None):
        r"""ShowScriptDetailRequest

        The model defined in huaweicloud sdk

        :param script_id: 脚本ID。
        :type script_id: str
        :param script_task_id: 执行脚本的任务ID
        :type script_task_id: str
        """
        
        

        self._script_id = None
        self._script_task_id = None
        self.discriminator = None

        self.script_id = script_id
        if script_task_id is not None:
            self.script_task_id = script_task_id

    @property
    def script_id(self):
        r"""Gets the script_id of this ShowScriptDetailRequest.

        脚本ID。

        :return: The script_id of this ShowScriptDetailRequest.
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        r"""Sets the script_id of this ShowScriptDetailRequest.

        脚本ID。

        :param script_id: The script_id of this ShowScriptDetailRequest.
        :type script_id: str
        """
        self._script_id = script_id

    @property
    def script_task_id(self):
        r"""Gets the script_task_id of this ShowScriptDetailRequest.

        执行脚本的任务ID

        :return: The script_task_id of this ShowScriptDetailRequest.
        :rtype: str
        """
        return self._script_task_id

    @script_task_id.setter
    def script_task_id(self, script_task_id):
        r"""Sets the script_task_id of this ShowScriptDetailRequest.

        执行脚本的任务ID

        :param script_task_id: The script_task_id of this ShowScriptDetailRequest.
        :type script_task_id: str
        """
        self._script_task_id = script_task_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowScriptDetailRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
